import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::AmplifyUIBuilder::Theme Resource Type
 */
export declare class Theme extends pulumi.CustomResource {
    /**
     * Get an existing Theme resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Theme;
    /**
     * Returns true if the given object is an instance of Theme.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Theme;
    /**
     * The unique ID for the Amplify app associated with the theme.
     */
    readonly appId: pulumi.Output<string | undefined>;
    /**
     * The ID for the theme.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The time that the theme was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The name of the backend environment that is a part of the Amplify app.
     */
    readonly environmentName: pulumi.Output<string | undefined>;
    /**
     * The time that the theme was modified.
     */
    readonly modifiedAt: pulumi.Output<string>;
    /**
     * The name of the theme.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Describes the properties that can be overriden to customize a theme.
     */
    readonly overrides: pulumi.Output<outputs.amplifyuibuilder.ThemeValues[] | undefined>;
    /**
     * One or more key-value pairs to use when tagging the theme.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of key-value pairs that defines the properties of the theme.
     */
    readonly values: pulumi.Output<outputs.amplifyuibuilder.ThemeValues[] | undefined>;
    /**
     * Create a Theme resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ThemeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Theme resource.
 */
export interface ThemeArgs {
    /**
     * The unique ID for the Amplify app associated with the theme.
     */
    appId?: pulumi.Input<string>;
    /**
     * The name of the backend environment that is a part of the Amplify app.
     */
    environmentName?: pulumi.Input<string>;
    /**
     * The name of the theme.
     */
    name?: pulumi.Input<string>;
    /**
     * Describes the properties that can be overriden to customize a theme.
     */
    overrides?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ThemeValuesArgs>[]>;
    /**
     * One or more key-value pairs to use when tagging the theme.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of key-value pairs that defines the properties of the theme.
     */
    values?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ThemeValuesArgs>[]>;
}
