import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::ApiGateway::DomainNameAccessAssociation.
 */
export declare class DomainNameAccessAssociation extends pulumi.CustomResource {
    /**
     * Get an existing DomainNameAccessAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DomainNameAccessAssociation;
    /**
     * Returns true if the given object is an instance of DomainNameAccessAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainNameAccessAssociation;
    /**
     * The source of the domain name access association resource.
     */
    readonly accessAssociationSource: pulumi.Output<string>;
    /**
     * The source type of the domain name access association resource.
     */
    readonly accessAssociationSourceType: pulumi.Output<enums.apigateway.DomainNameAccessAssociationAccessAssociationSourceType>;
    /**
     * The amazon resource name (ARN) of the domain name access association resource.
     */
    readonly domainNameAccessAssociationArn: pulumi.Output<string>;
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    readonly domainNameArn: pulumi.Output<string>;
    /**
     * An array of arbitrary tags (key-value pairs) to associate with the domainname access association.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a DomainNameAccessAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainNameAccessAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DomainNameAccessAssociation resource.
 */
export interface DomainNameAccessAssociationArgs {
    /**
     * The source of the domain name access association resource.
     */
    accessAssociationSource: pulumi.Input<string>;
    /**
     * The source type of the domain name access association resource.
     */
    accessAssociationSourceType: pulumi.Input<enums.apigateway.DomainNameAccessAssociationAccessAssociationSourceType>;
    /**
     * The amazon resource name (ARN) of the domain name resource.
     */
    domainNameArn: pulumi.Input<string>;
    /**
     * An array of arbitrary tags (key-value pairs) to associate with the domainname access association.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
