import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::ApiMapping`` resource contains an API mapping. An API mapping relates a path of your custom domain name to a stage of your API. A custom domain name can have multiple API mappings, but the paths can't overlap. A custom domain can map only to APIs of the same protocol type. For more information, see [CreateApiMapping](https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/domainnames-domainname-apimappings.html#CreateApiMapping) in the *Amazon API Gateway V2 API Reference*.
 */
export declare function getApiMapping(args: GetApiMappingArgs, opts?: pulumi.InvokeOptions): Promise<GetApiMappingResult>;
export interface GetApiMappingArgs {
    /**
     * The API mapping resource ID.
     */
    apiMappingId: string;
    /**
     * The domain name.
     */
    domainName: string;
}
export interface GetApiMappingResult {
    /**
     * The identifier of the API.
     */
    readonly apiId?: string;
    /**
     * The API mapping resource ID.
     */
    readonly apiMappingId?: string;
    /**
     * The API mapping key.
     */
    readonly apiMappingKey?: string;
    /**
     * The API stage.
     */
    readonly stage?: string;
}
/**
 * The ``AWS::ApiGatewayV2::ApiMapping`` resource contains an API mapping. An API mapping relates a path of your custom domain name to a stage of your API. A custom domain name can have multiple API mappings, but the paths can't overlap. A custom domain can map only to APIs of the same protocol type. For more information, see [CreateApiMapping](https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/domainnames-domainname-apimappings.html#CreateApiMapping) in the *Amazon API Gateway V2 API Reference*.
 */
export declare function getApiMappingOutput(args: GetApiMappingOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApiMappingResult>;
export interface GetApiMappingOutputArgs {
    /**
     * The API mapping resource ID.
     */
    apiMappingId: pulumi.Input<string>;
    /**
     * The domain name.
     */
    domainName: pulumi.Input<string>;
}
