import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getIntegration(args: GetIntegrationArgs, opts?: pulumi.InvokeOptions): Promise<GetIntegrationResult>;
export interface GetIntegrationArgs {
    /**
     * The API identifier.
     */
    apiId: string;
    /**
     * The integration ID.
     */
    integrationId: string;
}
export interface GetIntegrationResult {
    /**
     * The ID of the VPC link for a private integration. Supported only for HTTP APIs.
     */
    readonly connectionId?: string;
    /**
     * The type of the network connection to the integration endpoint. Specify INTERNET for connections through the public routable internet or VPC_LINK for private connections between API Gateway and resources in a VPC. The default value is INTERNET.
     */
    readonly connectionType?: string;
    /**
     * Supported only for WebSocket APIs. Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT.
     */
    readonly contentHandlingStrategy?: string;
    /**
     * Specifies the credentials required for the integration, if any. For AWS integrations, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify the string arn:aws:iam::*:user/*. To use resource-based permissions on supported AWS services, don't specify this parameter.
     */
    readonly credentialsArn?: string;
    /**
     * The description of the integration.
     */
    readonly description?: string;
    /**
     * The integration ID.
     */
    readonly integrationId?: string;
    /**
     * Specifies the integration's HTTP method type.
     */
    readonly integrationMethod?: string;
    /**
     * Supported only for HTTP API AWS_PROXY integrations. Specifies the AWS service action to invoke.
     */
    readonly integrationSubtype?: string;
    /**
     * The integration type of an integration.
     */
    readonly integrationType?: string;
    /**
     * For a Lambda integration, specify the URI of a Lambda function. For an HTTP integration, specify a fully-qualified URL. For an HTTP API private integration, specify the ARN of an Application Load Balancer listener, Network Load Balancer listener, or AWS Cloud Map service.
     */
    readonly integrationUri?: string;
    /**
     * Specifies the pass-through behavior for incoming requests based on the Content-Type header in the request, and the available mapping templates specified as the requestTemplates property on the Integration resource. There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and NEVER. Supported only for WebSocket APIs.
     */
    readonly passthroughBehavior?: string;
    /**
     * Specifies the format of the payload sent to an integration. Required for HTTP APIs. For HTTP APIs, supported values for Lambda proxy integrations are 1.0 and 2.0 For all other integrations, 1.0 is the only supported value.
     */
    readonly payloadFormatVersion?: string;
    /**
     * A key-value map specifying parameters.
     */
    readonly requestParameters?: {
        [key: string]: string;
    };
    /**
     * A map of Velocity templates that are applied on the request payload based on the value of the Content-Type header sent by the client.
     */
    readonly requestTemplates?: {
        [key: string]: string;
    };
    /**
     * Parameters that transform the HTTP response from a backend integration before returning the response to clients. Supported only for HTTP APIs.
     */
    readonly responseParameters?: {
        [key: string]: outputs.apigatewayv2.IntegrationResponseParameterMap;
    };
    /**
     * The template selection expression for the integration. Supported only for WebSocket APIs.
     */
    readonly templateSelectionExpression?: string;
    /**
     * Custom timeout between 50 and 29000 milliseconds for WebSocket APIs and between 50 and 30000 milliseconds for HTTP APIs. The default timeout is 29 seconds for WebSocket APIs and 30 seconds for HTTP APIs.
     */
    readonly timeoutInMillis?: number;
    /**
     * The TLS configuration for a private integration. If you specify a TLS configuration, private integration traffic uses the HTTPS protocol. Supported only for HTTP APIs.
     */
    readonly tlsConfig?: outputs.apigatewayv2.IntegrationTlsConfig;
}
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getIntegrationOutput(args: GetIntegrationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIntegrationResult>;
export interface GetIntegrationOutputArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The integration ID.
     */
    integrationId: pulumi.Input<string>;
}
