import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AppSync Api
 */
export declare class Api extends pulumi.CustomResource {
    /**
     * Get an existing Api resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Api;
    /**
     * Returns true if the given object is an instance of Api.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Api;
    /**
     * The Amazon Resource Name (ARN) of the AppSync Api
     */
    readonly apiArn: pulumi.Output<string>;
    /**
     * The unique identifier for the AppSync Api generated by the service
     */
    readonly apiId: pulumi.Output<string>;
    readonly dns: pulumi.Output<outputs.appsync.ApiDnsMap>;
    /**
     * Describes the authorization configuration for connections, message publishing, message subscriptions, and logging for an Event API.
     */
    readonly eventConfig: pulumi.Output<outputs.appsync.ApiEventConfig | undefined>;
    /**
     * The name of the `Api` .
     */
    readonly name: pulumi.Output<string>;
    /**
     * The owner contact information for an API resource.
     *
     * This field accepts any string input with a length of 0 - 256 characters.
     */
    readonly ownerContact: pulumi.Output<string | undefined>;
    /**
     * A set of tags (key-value pairs) for this API.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Api resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApiArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Api resource.
 */
export interface ApiArgs {
    /**
     * Describes the authorization configuration for connections, message publishing, message subscriptions, and logging for an Event API.
     */
    eventConfig?: pulumi.Input<inputs.appsync.ApiEventConfigArgs>;
    /**
     * The name of the `Api` .
     */
    name?: pulumi.Input<string>;
    /**
     * The owner contact information for an API resource.
     *
     * This field accepts any string input with a length of 0 - 256 characters.
     */
    ownerContact?: pulumi.Input<string>;
    /**
     * A set of tags (key-value pairs) for this API.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
