import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppSync::DomainName
 */
export declare class DomainName extends pulumi.CustomResource {
    /**
     * Get an existing DomainName resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DomainName;
    /**
     * Returns true if the given object is an instance of DomainName.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainName;
    /**
     * The domain name provided by AWS AppSync .
     */
    readonly appSyncDomainName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the certificate. This will be an AWS Certificate Manager certificate.
     */
    readonly certificateArn: pulumi.Output<string>;
    /**
     * The decription for your domain name.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The domain name.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) for the Domain Name.
     */
    readonly domainNameArn: pulumi.Output<string>;
    /**
     * The ID of your Amazon Route 53 hosted zone.
     */
    readonly hostedZoneId: pulumi.Output<string>;
    /**
     * A set of tags (key-value pairs) for this domain name.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DomainName resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainNameArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DomainName resource.
 */
export interface DomainNameArgs {
    /**
     * The Amazon Resource Name (ARN) of the certificate. This will be an AWS Certificate Manager certificate.
     */
    certificateArn: pulumi.Input<string>;
    /**
     * The decription for your domain name.
     */
    description?: pulumi.Input<string>;
    /**
     * The domain name.
     */
    domainName: pulumi.Input<string>;
    /**
     * A set of tags (key-value pairs) for this domain name.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
