import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Represents an association between an ID mapping workflow and a collaboration
 */
export declare function getIdMappingTable(args: GetIdMappingTableArgs, opts?: pulumi.InvokeOptions): Promise<GetIdMappingTableResult>;
export interface GetIdMappingTableArgs {
    /**
     * The unique identifier of the ID mapping table identifier that you want to retrieve.
     */
    idMappingTableIdentifier: string;
    /**
     * The unique identifier of the membership resource for the ID mapping table.
     */
    membershipIdentifier: string;
}
export interface GetIdMappingTableResult {
    /**
     * The Amazon Resource Name (ARN) of the ID mapping table.
     */
    readonly arn?: string;
    /**
     * The Amazon Resource Name (ARN) of the collaboration that contains this ID mapping table.
     */
    readonly collaborationArn?: string;
    /**
     * The unique identifier of the collaboration that contains this ID mapping table.
     */
    readonly collaborationIdentifier?: string;
    /**
     * The description of the ID mapping table.
     */
    readonly description?: string;
    /**
     * The unique identifier of the ID mapping table identifier that you want to retrieve.
     */
    readonly idMappingTableIdentifier?: string;
    readonly inputReferenceProperties?: outputs.cleanrooms.IdMappingTableInputReferenceProperties;
    /**
     * The Amazon Resource Name (ARN) of the AWS KMS key.
     */
    readonly kmsKeyArn?: string;
    /**
     * The Amazon Resource Name (ARN) of the membership resource for the ID mapping table.
     */
    readonly membershipArn?: string;
    /**
     * An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents an association between an ID mapping workflow and a collaboration
 */
export declare function getIdMappingTableOutput(args: GetIdMappingTableOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIdMappingTableResult>;
export interface GetIdMappingTableOutputArgs {
    /**
     * The unique identifier of the ID mapping table identifier that you want to retrieve.
     */
    idMappingTableIdentifier: pulumi.Input<string>;
    /**
     * The unique identifier of the membership resource for the ID mapping table.
     */
    membershipIdentifier: pulumi.Input<string>;
}
