import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The distribution tenant.
 */
export declare class DistributionTenant extends pulumi.CustomResource {
    /**
     * Get an existing DistributionTenant resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DistributionTenant;
    /**
     * Returns true if the given object is an instance of DistributionTenant.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DistributionTenant;
    /**
     * The Amazon Resource Name (ARN) of the distribution tenant.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the distribution tenant.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The ID of the connection group for the distribution tenant. If you don't specify a connection group, CloudFront uses the default connection group.
     */
    readonly connectionGroupId: pulumi.Output<string | undefined>;
    /**
     * The date and time when the distribution tenant was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * Customizations for the distribution tenant. For each distribution tenant, you can specify the geographic restrictions, and the Amazon Resource Names (ARNs) for the ACM certificate and WAF web ACL. These are specific values that you can override or disable from the multi-tenant distribution that was used to create the distribution tenant.
     */
    readonly customizations: pulumi.Output<outputs.cloudfront.DistributionTenantCustomizations | undefined>;
    /**
     * The ID of the multi-tenant distribution.
     */
    readonly distributionId: pulumi.Output<string>;
    readonly domainResults: pulumi.Output<outputs.cloudfront.DistributionTenantDomainResult[]>;
    /**
     * The domains associated with the distribution tenant.
     */
    readonly domains: pulumi.Output<string[]>;
    /**
     * The current version of the distribution tenant.
     */
    readonly eTag: pulumi.Output<string>;
    /**
     * Indicates whether the distribution tenant is in an enabled state. If disabled, the distribution tenant won't serve traffic.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The date and time when the distribution tenant was updated.
     */
    readonly lastModifiedTime: pulumi.Output<string>;
    /**
     * An object that represents the request for the Amazon CloudFront managed ACM certificate.
     */
    readonly managedCertificateRequest: pulumi.Output<outputs.cloudfront.DistributionTenantManagedCertificateRequest | undefined>;
    /**
     * The name of the distribution tenant.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of parameter values to add to the resource. A parameter is specified as a key-value pair. A valid parameter value must exist for any parameter that is marked as required in the multi-tenant distribution.
     */
    readonly parameters: pulumi.Output<outputs.cloudfront.DistributionTenantParameter[] | undefined>;
    /**
     * The status of the distribution tenant.
     */
    readonly status: pulumi.Output<string>;
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DistributionTenant resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DistributionTenantArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DistributionTenant resource.
 */
export interface DistributionTenantArgs {
    /**
     * The ID of the connection group for the distribution tenant. If you don't specify a connection group, CloudFront uses the default connection group.
     */
    connectionGroupId?: pulumi.Input<string>;
    /**
     * Customizations for the distribution tenant. For each distribution tenant, you can specify the geographic restrictions, and the Amazon Resource Names (ARNs) for the ACM certificate and WAF web ACL. These are specific values that you can override or disable from the multi-tenant distribution that was used to create the distribution tenant.
     */
    customizations?: pulumi.Input<inputs.cloudfront.DistributionTenantCustomizationsArgs>;
    /**
     * The ID of the multi-tenant distribution.
     */
    distributionId: pulumi.Input<string>;
    /**
     * The domains associated with the distribution tenant.
     */
    domains: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Indicates whether the distribution tenant is in an enabled state. If disabled, the distribution tenant won't serve traffic.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * An object that represents the request for the Amazon CloudFront managed ACM certificate.
     */
    managedCertificateRequest?: pulumi.Input<inputs.cloudfront.DistributionTenantManagedCertificateRequestArgs>;
    /**
     * The name of the distribution tenant.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of parameter values to add to the resource. A parameter is specified as a key-value pair. A valid parameter value must exist for any parameter that is marked as required in the multi-tenant distribution.
     */
    parameters?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionTenantParameterArgs>[]>;
    /**
     * A complex type that contains zero or more ``Tag`` elements.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
