import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The Amazon CloudTrail dashboard resource allows customers to manage managed dashboards and create custom dashboards. You can manually refresh custom and managed dashboards. For custom dashboards, you can also set up an automatic refresh schedule and modify dashboard widgets.
 */
export declare function getDashboard(args: GetDashboardArgs, opts?: pulumi.InvokeOptions): Promise<GetDashboardResult>;
export interface GetDashboardArgs {
    /**
     * The ARN of the dashboard.
     */
    dashboardArn: string;
}
export interface GetDashboardResult {
    /**
     * The timestamp of the dashboard creation.
     */
    readonly createdTimestamp?: string;
    /**
     * The ARN of the dashboard.
     */
    readonly dashboardArn?: string;
    /**
     * The name of the dashboard.
     */
    readonly name?: string;
    /**
     * Configures the automatic refresh schedule for the dashboard. Includes the frequency unit (DAYS or HOURS) and value, as well as the status (ENABLED or DISABLED) of the refresh schedule.
     */
    readonly refreshSchedule?: outputs.cloudtrail.DashboardRefreshSchedule;
    /**
     * The status of the dashboard. Values are CREATING, CREATED, UPDATING, UPDATED and DELETING.
     */
    readonly status?: enums.cloudtrail.DashboardStatus;
    /**
     * A list of tags.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Indicates whether the dashboard is protected from termination.
     */
    readonly terminationProtectionEnabled?: boolean;
    /**
     * The type of the dashboard. Values are CUSTOM and MANAGED.
     */
    readonly type?: enums.cloudtrail.DashboardType;
    /**
     * The timestamp showing when the dashboard was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.
     */
    readonly updatedTimestamp?: string;
    /**
     * List of widgets on the dashboard
     */
    readonly widgets?: outputs.cloudtrail.DashboardWidget[];
}
/**
 * The Amazon CloudTrail dashboard resource allows customers to manage managed dashboards and create custom dashboards. You can manually refresh custom and managed dashboards. For custom dashboards, you can also set up an automatic refresh schedule and modify dashboard widgets.
 */
export declare function getDashboardOutput(args: GetDashboardOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDashboardResult>;
export interface GetDashboardOutputArgs {
    /**
     * The ARN of the dashboard.
     */
    dashboardArn: pulumi.Input<string>;
}
