import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Schema for AWS::CodeStarConnections::Connection resource which can be used to connect external source providers with AWS CodePipeline
 */
export declare function getConnection(args: GetConnectionArgs, opts?: pulumi.InvokeOptions): Promise<GetConnectionResult>;
export interface GetConnectionArgs {
    /**
     * The Amazon Resource Name (ARN) of the  connection. The ARN is used as the connection reference when the connection is shared between AWS services.
     */
    connectionArn: string;
}
export interface GetConnectionResult {
    /**
     * The Amazon Resource Name (ARN) of the  connection. The ARN is used as the connection reference when the connection is shared between AWS services.
     */
    readonly connectionArn?: string;
    /**
     * The current status of the connection.
     */
    readonly connectionStatus?: string;
    /**
     * The name of the external provider where your third-party code repository is configured. For Bitbucket, this is the account ID of the owner of the Bitbucket repository.
     */
    readonly ownerAccountId?: string;
    /**
     * Specifies the tags applied to a connection.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Schema for AWS::CodeStarConnections::Connection resource which can be used to connect external source providers with AWS CodePipeline
 */
export declare function getConnectionOutput(args: GetConnectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConnectionResult>;
export interface GetConnectionOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the  connection. The ARN is used as the connection reference when the connection is shared between AWS services.
     */
    connectionArn: pulumi.Input<string>;
}
