import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Cognito::IdentityPool
 */
export declare class IdentityPool extends pulumi.CustomResource {
    /**
     * Get an existing IdentityPool resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IdentityPool;
    /**
     * Returns true if the given object is an instance of IdentityPool.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdentityPool;
    /**
     * Enables the Basic (Classic) authentication flow.
     */
    readonly allowClassicFlow: pulumi.Output<boolean | undefined>;
    /**
     * Specifies whether the identity pool supports unauthenticated logins.
     */
    readonly allowUnauthenticatedIdentities: pulumi.Output<boolean>;
    readonly awsId: pulumi.Output<string>;
    /**
     * The events to configure.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPool` for more information about the expected schema for this property.
     */
    readonly cognitoEvents: pulumi.Output<any | undefined>;
    /**
     * The Amazon Cognito user pools and their client IDs.
     */
    readonly cognitoIdentityProviders: pulumi.Output<outputs.cognito.IdentityPoolCognitoIdentityProvider[] | undefined>;
    /**
     * Configuration options for configuring Amazon Cognito streams.
     */
    readonly cognitoStreams: pulumi.Output<outputs.cognito.IdentityPoolCognitoStreams | undefined>;
    /**
     * The "domain" Amazon Cognito uses when referencing your users. This name acts as a placeholder that allows your backend and the Amazon Cognito service to communicate about the developer provider. For the `DeveloperProviderName` , you can use letters and periods (.), underscores (_), and dashes (-).
     *
     * *Minimum length* : 1
     *
     * *Maximum length* : 100
     */
    readonly developerProviderName: pulumi.Output<string | undefined>;
    /**
     * The name of your Amazon Cognito identity pool.
     *
     * *Minimum length* : 1
     *
     * *Maximum length* : 128
     *
     * *Pattern* : `[\w\s+=,.@-]+`
     */
    readonly identityPoolName: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly identityPoolTags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The name of the Amazon Cognito identity pool, returned as a string.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Names (ARNs) of the OpenID connect providers.
     */
    readonly openIdConnectProviderArns: pulumi.Output<string[] | undefined>;
    /**
     * The configuration options to be applied to the identity pool.
     */
    readonly pushSync: pulumi.Output<outputs.cognito.IdentityPoolPushSync | undefined>;
    /**
     * The Amazon Resource Names (ARNs) of the Security Assertion Markup Language (SAML) providers.
     */
    readonly samlProviderArns: pulumi.Output<string[] | undefined>;
    /**
     * Key-value pairs that map provider names to provider app IDs.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPool` for more information about the expected schema for this property.
     */
    readonly supportedLoginProviders: pulumi.Output<any | undefined>;
    /**
     * Create a IdentityPool resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdentityPoolArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IdentityPool resource.
 */
export interface IdentityPoolArgs {
    /**
     * Enables the Basic (Classic) authentication flow.
     */
    allowClassicFlow?: pulumi.Input<boolean>;
    /**
     * Specifies whether the identity pool supports unauthenticated logins.
     */
    allowUnauthenticatedIdentities: pulumi.Input<boolean>;
    /**
     * The events to configure.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPool` for more information about the expected schema for this property.
     */
    cognitoEvents?: any;
    /**
     * The Amazon Cognito user pools and their client IDs.
     */
    cognitoIdentityProviders?: pulumi.Input<pulumi.Input<inputs.cognito.IdentityPoolCognitoIdentityProviderArgs>[]>;
    /**
     * Configuration options for configuring Amazon Cognito streams.
     */
    cognitoStreams?: pulumi.Input<inputs.cognito.IdentityPoolCognitoStreamsArgs>;
    /**
     * The "domain" Amazon Cognito uses when referencing your users. This name acts as a placeholder that allows your backend and the Amazon Cognito service to communicate about the developer provider. For the `DeveloperProviderName` , you can use letters and periods (.), underscores (_), and dashes (-).
     *
     * *Minimum length* : 1
     *
     * *Maximum length* : 100
     */
    developerProviderName?: pulumi.Input<string>;
    /**
     * The name of your Amazon Cognito identity pool.
     *
     * *Minimum length* : 1
     *
     * *Maximum length* : 128
     *
     * *Pattern* : `[\w\s+=,.@-]+`
     */
    identityPoolName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    identityPoolTags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The Amazon Resource Names (ARNs) of the OpenID connect providers.
     */
    openIdConnectProviderArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The configuration options to be applied to the identity pool.
     */
    pushSync?: pulumi.Input<inputs.cognito.IdentityPoolPushSyncArgs>;
    /**
     * The Amazon Resource Names (ARNs) of the Security Assertion Markup Language (SAML) providers.
     */
    samlProviderArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Key-value pairs that map provider names to provider app IDs.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Cognito::IdentityPool` for more information about the expected schema for this property.
     */
    supportedLoginProviders?: any;
}
