import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An event trigger resource of Amazon Connect Customer Profiles
 */
export declare function getEventTrigger(args: GetEventTriggerArgs, opts?: pulumi.InvokeOptions): Promise<GetEventTriggerResult>;
export interface GetEventTriggerArgs {
    /**
     * The unique name of the domain.
     */
    domainName: string;
    /**
     * The unique name of the event trigger.
     */
    eventTriggerName: string;
}
export interface GetEventTriggerResult {
    /**
     * The timestamp of when the event trigger was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the event trigger.
     */
    readonly description?: string;
    /**
     * A list of conditions that determine when an event should trigger the destination.
     */
    readonly eventTriggerConditions?: outputs.customerprofiles.EventTriggerCondition[];
    /**
     * Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
     */
    readonly eventTriggerLimits?: outputs.customerprofiles.EventTriggerLimits;
    /**
     * The timestamp of when the event trigger was most recently updated.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The unique name of the object type.
     */
    readonly objectTypeName?: string;
    /**
     * The destination is triggered only for profiles that meet the criteria of a segment definition.
     */
    readonly segmentFilter?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * An event trigger resource of Amazon Connect Customer Profiles
 */
export declare function getEventTriggerOutput(args: GetEventTriggerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEventTriggerResult>;
export interface GetEventTriggerOutputArgs {
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
    /**
     * The unique name of the event trigger.
     */
    eventTriggerName: pulumi.Input<string>;
}
