import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Group profiles represent groups of Amazon DataZone users. Groups can be manually created, or mapped to Active Directory groups of enterprise customers. In Amazon DataZone, groups serve two purposes. First, a group can map to a team of users in the organizational chart, and thus reduce the administrative work of a Amazon DataZone project owner when there are new employees joining or leaving a team. Second, corporate administrators use Active Directory groups to manage and update user statuses and so Amazon DataZone domain administrators can use these group memberships to implement Amazon DataZone domain policies.
 */
export declare function getGroupProfile(args: GetGroupProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetGroupProfileResult>;
export interface GetGroupProfileArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the group profile is created.
     */
    domainId: string;
    /**
     * The ID of the Amazon DataZone group profile.
     */
    id: string;
}
export interface GetGroupProfileResult {
    /**
     * The identifier of the Amazon DataZone domain in which the group profile is created.
     */
    readonly domainId?: string;
    /**
     * The group-name of the Group Profile.
     */
    readonly groupName?: string;
    /**
     * The ID of the Amazon DataZone group profile.
     */
    readonly id?: string;
    /**
     * The status of a group profile.
     */
    readonly status?: enums.datazone.GroupProfileStatus;
}
/**
 * Group profiles represent groups of Amazon DataZone users. Groups can be manually created, or mapped to Active Directory groups of enterprise customers. In Amazon DataZone, groups serve two purposes. First, a group can map to a team of users in the organizational chart, and thus reduce the administrative work of a Amazon DataZone project owner when there are new employees joining or leaving a team. Second, corporate administrators use Active Directory groups to manage and update user statuses and so Amazon DataZone domain administrators can use these group memberships to implement Amazon DataZone domain policies.
 */
export declare function getGroupProfileOutput(args: GetGroupProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGroupProfileResult>;
export interface GetGroupProfileOutputArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the group profile is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone group profile.
     */
    id: pulumi.Input<string>;
}
