import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::DataZone::ProjectMembership Resource Type
 */
export declare class ProjectMembership extends pulumi.CustomResource {
    /**
     * Get an existing ProjectMembership resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ProjectMembership;
    /**
     * Returns true if the given object is an instance of ProjectMembership.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProjectMembership;
    /**
     * The designated role of a project member.
     */
    readonly designation: pulumi.Output<enums.datazone.ProjectMembershipUserDesignation>;
    /**
     * The ID of the Amazon DataZone domain in which project membership is created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The details about a project member.
     */
    readonly member: pulumi.Output<outputs.datazone.ProjectMembershipMember0Properties | outputs.datazone.ProjectMembershipMember1Properties>;
    /**
     * The ID of the project for which this project membership was created.
     */
    readonly projectIdentifier: pulumi.Output<string>;
    /**
     * Create a ProjectMembership resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectMembershipArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ProjectMembership resource.
 */
export interface ProjectMembershipArgs {
    /**
     * The designated role of a project member.
     */
    designation: pulumi.Input<enums.datazone.ProjectMembershipUserDesignation>;
    /**
     * The ID of the Amazon DataZone domain in which project membership is created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The details about a project member.
     */
    member: pulumi.Input<inputs.datazone.ProjectMembershipMember0PropertiesArgs | inputs.datazone.ProjectMembershipMember1PropertiesArgs>;
    /**
     * The ID of the project for which this project membership was created.
     */
    projectIdentifier: pulumi.Input<string>;
}
