import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::DirectoryService::SimpleAD
 */
export declare class SimpleAd extends pulumi.CustomResource {
    /**
     * Get an existing SimpleAd resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SimpleAd;
    /**
     * Returns true if the given object is an instance of SimpleAd.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SimpleAd;
    /**
     * The alias for a directory.
     */
    readonly alias: pulumi.Output<string>;
    /**
     * The name of the configuration set.
     */
    readonly createAlias: pulumi.Output<boolean | undefined>;
    /**
     * Description for the directory.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The unique identifier for a directory.
     */
    readonly directoryId: pulumi.Output<string>;
    /**
     * The IP addresses of the DNS servers for the directory, such as [ "172.31.3.154", "172.31.63.203" ].
     */
    readonly dnsIpAddresses: pulumi.Output<string[]>;
    /**
     * Whether to enable single sign-on for a Simple Active Directory in AWS.
     */
    readonly enableSso: pulumi.Output<boolean | undefined>;
    /**
     * The fully qualified domain name for the AWS Managed Simple AD directory.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The password for the default administrative user named Admin.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * The NetBIOS name for your domain.
     */
    readonly shortName: pulumi.Output<string | undefined>;
    /**
     * The size of the directory.
     */
    readonly size: pulumi.Output<string>;
    /**
     * VPC settings of the Simple AD directory server in AWS.
     */
    readonly vpcSettings: pulumi.Output<outputs.directoryservice.SimpleAdVpcSettings>;
    /**
     * Create a SimpleAd resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SimpleAdArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SimpleAd resource.
 */
export interface SimpleAdArgs {
    /**
     * The name of the configuration set.
     */
    createAlias?: pulumi.Input<boolean>;
    /**
     * Description for the directory.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether to enable single sign-on for a Simple Active Directory in AWS.
     */
    enableSso?: pulumi.Input<boolean>;
    /**
     * The fully qualified domain name for the AWS Managed Simple AD directory.
     */
    name?: pulumi.Input<string>;
    /**
     * The password for the default administrative user named Admin.
     */
    password?: pulumi.Input<string>;
    /**
     * The NetBIOS name for your domain.
     */
    shortName?: pulumi.Input<string>;
    /**
     * The size of the directory.
     */
    size: pulumi.Input<string>;
    /**
     * VPC settings of the Simple AD directory server in AWS.
     */
    vpcSettings: pulumi.Input<inputs.directoryservice.SimpleAdVpcSettingsArgs>;
}
