import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare class StudioSessionMapping extends pulumi.CustomResource {
    /**
     * Get an existing StudioSessionMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StudioSessionMapping;
    /**
     * Returns true if the given object is an instance of StudioSessionMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StudioSessionMapping;
    /**
     * The name of the user or group. For more information, see UserName and DisplayName in the AWS SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified.
     */
    readonly identityName: pulumi.Output<string>;
    /**
     * Specifies whether the identity to map to the Studio is a user or a group.
     */
    readonly identityType: pulumi.Output<enums.emr.StudioSessionMappingIdentityType>;
    /**
     * The Amazon Resource Name (ARN) for the session policy that will be applied to the user or group. Session policies refine Studio user permissions without the need to use multiple IAM user roles.
     */
    readonly sessionPolicyArn: pulumi.Output<string>;
    /**
     * The ID of the Amazon EMR Studio to which the user or group will be mapped.
     */
    readonly studioId: pulumi.Output<string>;
    /**
     * Create a StudioSessionMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StudioSessionMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StudioSessionMapping resource.
 */
export interface StudioSessionMappingArgs {
    /**
     * The name of the user or group. For more information, see UserName and DisplayName in the AWS SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified.
     */
    identityName: pulumi.Input<string>;
    /**
     * Specifies whether the identity to map to the Studio is a user or a group.
     */
    identityType: pulumi.Input<enums.emr.StudioSessionMappingIdentityType>;
    /**
     * The Amazon Resource Name (ARN) for the session policy that will be applied to the user or group. Session policies refine Studio user permissions without the need to use multiple IAM user roles.
     */
    sessionPolicyArn: pulumi.Input<string>;
    /**
     * The ID of the Amazon EMR Studio to which the user or group will be mapped.
     */
    studioId: pulumi.Input<string>;
}
