import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * IdMappingWorkflow defined in AWS Entity Resolution service
 */
export declare class IdMappingWorkflow extends pulumi.CustomResource {
    /**
     * Get an existing IdMappingWorkflow resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IdMappingWorkflow;
    /**
     * Returns true if the given object is an instance of IdMappingWorkflow.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdMappingWorkflow;
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the IdMappingWorkflow
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * An object which defines the ID mapping technique and any additional configurations.
     */
    readonly idMappingTechniques: pulumi.Output<outputs.entityresolution.IdMappingWorkflowIdMappingTechniques>;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    readonly inputSourceConfig: pulumi.Output<outputs.entityresolution.IdMappingWorkflowInputSource[]>;
    /**
     * A list of `IdMappingWorkflowOutputSource` objects, each of which contains fields `OutputS3Path` and `Output` .
     */
    readonly outputSourceConfig: pulumi.Output<outputs.entityresolution.IdMappingWorkflowOutputSource[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    readonly updatedAt: pulumi.Output<string>;
    readonly workflowArn: pulumi.Output<string>;
    /**
     * The name of the IdMappingWorkflow
     */
    readonly workflowName: pulumi.Output<string>;
    /**
     * Create a IdMappingWorkflow resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdMappingWorkflowArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IdMappingWorkflow resource.
 */
export interface IdMappingWorkflowArgs {
    /**
     * The description of the IdMappingWorkflow
     */
    description?: pulumi.Input<string>;
    /**
     * An object which defines the ID mapping technique and any additional configurations.
     */
    idMappingTechniques: pulumi.Input<inputs.entityresolution.IdMappingWorkflowIdMappingTechniquesArgs>;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    inputSourceConfig: pulumi.Input<pulumi.Input<inputs.entityresolution.IdMappingWorkflowInputSourceArgs>[]>;
    /**
     * A list of `IdMappingWorkflowOutputSource` objects, each of which contains fields `OutputS3Path` and `Output` .
     */
    outputSourceConfig?: pulumi.Input<pulumi.Input<inputs.entityresolution.IdMappingWorkflowOutputSourceArgs>[]>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    roleArn: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the IdMappingWorkflow
     */
    workflowName?: pulumi.Input<string>;
}
