import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Events::Rule
 */
export declare function getRule(args: GetRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetRuleResult>;
export interface GetRuleArgs {
    /**
     * The ARN of the rule, such as arn:aws:events:us-east-2:123456789012:rule/example.
     */
    arn: string;
}
export interface GetRuleResult {
    /**
     * The ARN of the rule, such as arn:aws:events:us-east-2:123456789012:rule/example.
     */
    readonly arn?: string;
    /**
     * The description of the rule.
     */
    readonly description?: string;
    /**
     * The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used.
     */
    readonly eventBusName?: string;
    /**
     * The event pattern of the rule. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Events::Rule` for more information about the expected schema for this property.
     */
    readonly eventPattern?: any;
    /**
     * The Amazon Resource Name (ARN) of the role that is used for target invocation.
     */
    readonly roleArn?: string;
    /**
     * The scheduling expression. For example, "cron(0 20 * * ? *)", "rate(5 minutes)". For more information, see Creating an Amazon EventBridge rule that runs on a schedule.
     */
    readonly scheduleExpression?: string;
    /**
     * The state of the rule.
     */
    readonly state?: enums.events.RuleState;
    /**
     * Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule.
     * Targets are the resources that are invoked when a rule is triggered.
     */
    readonly targets?: outputs.events.RuleTarget[];
}
/**
 * Resource Type definition for AWS::Events::Rule
 */
export declare function getRuleOutput(args: GetRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRuleResult>;
export interface GetRuleOutputArgs {
    /**
     * The ARN of the rule, such as arn:aws:events:us-east-2:123456789012:rule/example.
     */
    arn: pulumi.Input<string>;
}
