import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::ThreatIntelSet
 */
export declare function getThreatIntelSet(args: GetThreatIntelSetArgs, opts?: pulumi.InvokeOptions): Promise<GetThreatIntelSetResult>;
export interface GetThreatIntelSetArgs {
    /**
     * The unique ID of the detector of the GuardDuty account for which you want to create a `ThreatIntelSet` .
     *
     * To find the `detectorId` in the current Region, see the
     * Settings page in the GuardDuty console, or run the [ListDetectors](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html) API.
     */
    detectorId: string;
    /**
     * The unique ID of the `threatIntelSet` .
     */
    id: string;
}
export interface GetThreatIntelSetResult {
    /**
     * The unique ID of the `threatIntelSet` .
     */
    readonly id?: string;
    /**
     * The URI of the file that contains the ThreatIntelSet.
     */
    readonly location?: string;
    /**
     * A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
     */
    readonly name?: string;
    /**
     * The tags to be added to a new threat list resource. Each tag consists of a key and an optional value, both of which you define.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GuardDuty::ThreatIntelSet
 */
export declare function getThreatIntelSetOutput(args: GetThreatIntelSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetThreatIntelSetResult>;
export interface GetThreatIntelSetOutputArgs {
    /**
     * The unique ID of the detector of the GuardDuty account for which you want to create a `ThreatIntelSet` .
     *
     * To find the `detectorId` in the current Region, see the
     * Settings page in the GuardDuty console, or run the [ListDetectors](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html) API.
     */
    detectorId: pulumi.Input<string>;
    /**
     * The unique ID of the `threatIntelSet` .
     */
    id: pulumi.Input<string>;
}
