import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::PublishingDestination.
 */
export declare class PublishingDestination extends pulumi.CustomResource {
    /**
     * Get an existing PublishingDestination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PublishingDestination;
    /**
     * Returns true if the given object is an instance of PublishingDestination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PublishingDestination;
    /**
     * The ID of the publishing destination.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Contains the Amazon Resource Name (ARN) of the resource to publish to, such as an S3 bucket, and the ARN of the KMS key to use to encrypt published findings.
     */
    readonly destinationProperties: pulumi.Output<outputs.guardduty.PublishingDestinationCfnDestinationProperties>;
    /**
     * The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.
     */
    readonly destinationType: pulumi.Output<string>;
    /**
     * The ID of the GuardDuty detector associated with the publishing destination.
     */
    readonly detectorId: pulumi.Output<string>;
    /**
     * The time, in epoch millisecond format, at which GuardDuty was first unable to publish findings to the destination.
     */
    readonly publishingFailureStartTimestamp: pulumi.Output<string>;
    /**
     * The status of the publishing destination.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Describes a tag.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PublishingDestination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PublishingDestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PublishingDestination resource.
 */
export interface PublishingDestinationArgs {
    /**
     * Contains the Amazon Resource Name (ARN) of the resource to publish to, such as an S3 bucket, and the ARN of the KMS key to use to encrypt published findings.
     */
    destinationProperties: pulumi.Input<inputs.guardduty.PublishingDestinationCfnDestinationPropertiesArgs>;
    /**
     * The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.
     */
    destinationType: pulumi.Input<string>;
    /**
     * The ID of the GuardDuty detector associated with the publishing destination.
     */
    detectorId: pulumi.Input<string>;
    /**
     * Describes a tag.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
