import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Scheduled audits can be used to specify the checks you want to perform during an audit and how often the audit should be run.
 */
export declare class ScheduledAudit extends pulumi.CustomResource {
    /**
     * Get an existing ScheduledAudit resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ScheduledAudit;
    /**
     * Returns true if the given object is an instance of ScheduledAudit.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ScheduledAudit;
    /**
     * The day of the month on which the scheduled audit takes place. Can be 1 through 31 or LAST. This field is required if the frequency parameter is set to MONTHLY.
     */
    readonly dayOfMonth: pulumi.Output<string | undefined>;
    /**
     * The day of the week on which the scheduled audit takes place. Can be one of SUN, MON, TUE,WED, THU, FRI, or SAT. This field is required if the frequency parameter is set to WEEKLY or BIWEEKLY.
     */
    readonly dayOfWeek: pulumi.Output<enums.iot.ScheduledAuditDayOfWeek | undefined>;
    /**
     * How often the scheduled audit takes place. Can be one of DAILY, WEEKLY, BIWEEKLY, or MONTHLY.
     */
    readonly frequency: pulumi.Output<enums.iot.ScheduledAuditFrequency>;
    /**
     * The ARN (Amazon resource name) of the scheduled audit.
     */
    readonly scheduledAuditArn: pulumi.Output<string>;
    /**
     * The name you want to give to the scheduled audit.
     */
    readonly scheduledAuditName: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Which checks are performed during the scheduled audit. Checks must be enabled for your account.
     */
    readonly targetCheckNames: pulumi.Output<string[]>;
    /**
     * Create a ScheduledAudit resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ScheduledAuditArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ScheduledAudit resource.
 */
export interface ScheduledAuditArgs {
    /**
     * The day of the month on which the scheduled audit takes place. Can be 1 through 31 or LAST. This field is required if the frequency parameter is set to MONTHLY.
     */
    dayOfMonth?: pulumi.Input<string>;
    /**
     * The day of the week on which the scheduled audit takes place. Can be one of SUN, MON, TUE,WED, THU, FRI, or SAT. This field is required if the frequency parameter is set to WEEKLY or BIWEEKLY.
     */
    dayOfWeek?: pulumi.Input<enums.iot.ScheduledAuditDayOfWeek>;
    /**
     * How often the scheduled audit takes place. Can be one of DAILY, WEEKLY, BIWEEKLY, or MONTHLY.
     */
    frequency: pulumi.Input<enums.iot.ScheduledAuditFrequency>;
    /**
     * The name you want to give to the scheduled audit.
     */
    scheduledAuditName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Which checks are performed during the scheduled audit. Checks must be enabled for your account.
     */
    targetCheckNames: pulumi.Input<pulumi.Input<string>[]>;
}
