import * as pulumi from "@pulumi/pulumi";
/**
 * Resource schema for AWS::IoTTwinMaker::Scene
 */
export declare class Scene extends pulumi.CustomResource {
    /**
     * Get an existing Scene resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Scene;
    /**
     * Returns true if the given object is an instance of Scene.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Scene;
    /**
     * The ARN of the scene.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A list of capabilities that the scene uses to render.
     */
    readonly capabilities: pulumi.Output<string[] | undefined>;
    /**
     * The relative path that specifies the location of the content definition file.
     */
    readonly contentLocation: pulumi.Output<string>;
    /**
     * The date and time when the scene was created.
     */
    readonly creationDateTime: pulumi.Output<string>;
    /**
     * The description of the scene.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A key-value pair of generated scene metadata for the scene.
     */
    readonly generatedSceneMetadata: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * The ID of the scene.
     */
    readonly sceneId: pulumi.Output<string>;
    /**
     * A key-value pair of scene metadata for the scene.
     */
    readonly sceneMetadata: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The date and time of the current update.
     */
    readonly updateDateTime: pulumi.Output<string>;
    /**
     * The ID of the scene.
     */
    readonly workspaceId: pulumi.Output<string>;
    /**
     * Create a Scene resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SceneArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Scene resource.
 */
export interface SceneArgs {
    /**
     * A list of capabilities that the scene uses to render.
     */
    capabilities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The relative path that specifies the location of the content definition file.
     */
    contentLocation: pulumi.Input<string>;
    /**
     * The description of the scene.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the scene.
     */
    sceneId: pulumi.Input<string>;
    /**
     * A key-value pair of scene metadata for the scene.
     */
    sceneMetadata?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The ID of the scene.
     */
    workspaceId: pulumi.Input<string>;
}
