import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents an application that runs on an AWS Mainframe Modernization Environment
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The Amazon Resource Name (ARN) of the application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * The identifier of the application.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The application definition for a particular application. You can specify either inline JSON or an Amazon S3 bucket location.
     *
     * For information about application definitions, see the [AWS Mainframe Modernization User Guide](https://docs.aws.amazon.com/m2/latest/userguide/applications-m2-definition.html) .
     */
    readonly definition: pulumi.Output<outputs.m2.ApplicationDefinition0Properties | outputs.m2.ApplicationDefinition1Properties | undefined>;
    /**
     * The description of the application.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The type of the target platform for this application.
     */
    readonly engineType: pulumi.Output<enums.m2.ApplicationEngineType>;
    /**
     * The ID or the Amazon Resource Name (ARN) of the customer managed KMS Key used for encrypting application-related resources.
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    /**
     * The name of the application.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the role associated with the application.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The application definition for a particular application. You can specify either inline JSON or an Amazon S3 bucket location.
     *
     * For information about application definitions, see the [AWS Mainframe Modernization User Guide](https://docs.aws.amazon.com/m2/latest/userguide/applications-m2-definition.html) .
     */
    definition?: pulumi.Input<inputs.m2.ApplicationDefinition0PropertiesArgs | inputs.m2.ApplicationDefinition1PropertiesArgs>;
    /**
     * The description of the application.
     */
    description?: pulumi.Input<string>;
    /**
     * The type of the target platform for this application.
     */
    engineType: pulumi.Input<enums.m2.ApplicationEngineType>;
    /**
     * The ID or the Amazon Resource Name (ARN) of the customer managed KMS Key used for encrypting application-related resources.
     */
    kmsKeyId?: pulumi.Input<string>;
    /**
     * The name of the application.
     */
    name?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the role associated with the application.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
