import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::Neptune::DBClusterParameterGroup resource creates a new Amazon Neptune DB cluster parameter group
 */
export declare class DbClusterParameterGroup extends pulumi.CustomResource {
    /**
     * Get an existing DbClusterParameterGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbClusterParameterGroup;
    /**
     * Returns true if the given object is an instance of DbClusterParameterGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbClusterParameterGroup;
    /**
     * Provides the customer-specified description for this DB cluster parameter group.
     */
    readonly description: pulumi.Output<string>;
    /**
     * Must be neptune1 for engine versions prior to 1.2.0.0, or neptune1.2 for engine version 1.2.0.0 and higher.
     */
    readonly family: pulumi.Output<string>;
    /**
     * Provides the name of the DB cluster parameter group.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * An array of parameters to be modified. A maximum of 20 parameters can be modified in a single request.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Neptune::DBClusterParameterGroup` for more information about the expected schema for this property.
     */
    readonly parameters: pulumi.Output<any>;
    /**
     * The list of tags for the cluster parameter group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DbClusterParameterGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbClusterParameterGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbClusterParameterGroup resource.
 */
export interface DbClusterParameterGroupArgs {
    /**
     * Provides the customer-specified description for this DB cluster parameter group.
     */
    description: pulumi.Input<string>;
    /**
     * Must be neptune1 for engine versions prior to 1.2.0.0, or neptune1.2 for engine version 1.2.0.0 and higher.
     */
    family: pulumi.Input<string>;
    /**
     * Provides the name of the DB cluster parameter group.
     */
    name?: pulumi.Input<string>;
    /**
     * An array of parameters to be modified. A maximum of 20 parameters can be modified in a single request.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Neptune::DBClusterParameterGroup` for more information about the expected schema for this property.
     */
    parameters: any;
    /**
     * The list of tags for the cluster parameter group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
