import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::NetworkManager::SiteToSiteVpnAttachment Resource Type definition.
 */
export declare class SiteToSiteVpnAttachment extends pulumi.CustomResource {
    /**
     * Get an existing SiteToSiteVpnAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SiteToSiteVpnAttachment;
    /**
     * Returns true if the given object is an instance of SiteToSiteVpnAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SiteToSiteVpnAttachment;
    /**
     * The ID of the attachment.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * The policy rule number associated with the attachment.
     */
    readonly attachmentPolicyRuleNumber: pulumi.Output<number>;
    /**
     * The type of attachment.
     */
    readonly attachmentType: pulumi.Output<string>;
    /**
     * The ARN of a core network for the VPC attachment.
     */
    readonly coreNetworkArn: pulumi.Output<string>;
    /**
     * The ID of a core network where you're creating a site-to-site VPN attachment.
     */
    readonly coreNetworkId: pulumi.Output<string>;
    /**
     * Creation time of the attachment.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Region where the edge is located.
     */
    readonly edgeLocation: pulumi.Output<string>;
    /**
     * The name of the network function group attachment.
     */
    readonly networkFunctionGroupName: pulumi.Output<string | undefined>;
    /**
     * Owner account of the attachment.
     */
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    readonly proposedNetworkFunctionGroupChange: pulumi.Output<outputs.networkmanager.SiteToSiteVpnAttachmentProposedNetworkFunctionGroupChange | undefined>;
    /**
     * The attachment to move from one segment to another.
     */
    readonly proposedSegmentChange: pulumi.Output<outputs.networkmanager.SiteToSiteVpnAttachmentProposedSegmentChange | undefined>;
    /**
     * The ARN of the Resource.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The name of the segment that attachment is in.
     */
    readonly segmentName: pulumi.Output<string>;
    /**
     * The state of the attachment.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Tags for the attachment.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Last update time of the attachment.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * The ARN of the site-to-site VPN attachment.
     */
    readonly vpnConnectionArn: pulumi.Output<string>;
    /**
     * Create a SiteToSiteVpnAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SiteToSiteVpnAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SiteToSiteVpnAttachment resource.
 */
export interface SiteToSiteVpnAttachmentArgs {
    /**
     * The ID of a core network where you're creating a site-to-site VPN attachment.
     */
    coreNetworkId: pulumi.Input<string>;
    /**
     * The name of the network function group attachment.
     */
    networkFunctionGroupName?: pulumi.Input<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    proposedNetworkFunctionGroupChange?: pulumi.Input<inputs.networkmanager.SiteToSiteVpnAttachmentProposedNetworkFunctionGroupChangeArgs>;
    /**
     * The attachment to move from one segment to another.
     */
    proposedSegmentChange?: pulumi.Input<inputs.networkmanager.SiteToSiteVpnAttachmentProposedSegmentChangeArgs>;
    /**
     * Tags for the attachment.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ARN of the site-to-site VPN attachment.
     */
    vpnConnectionArn: pulumi.Input<string>;
}
