import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::NetworkManager::TransitGatewayRouteTableAttachment Resource Type definition.
 */
export declare class TransitGatewayRouteTableAttachment extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayRouteTableAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayRouteTableAttachment;
    /**
     * Returns true if the given object is an instance of TransitGatewayRouteTableAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayRouteTableAttachment;
    /**
     * The ID of the attachment.
     */
    readonly attachmentId: pulumi.Output<string>;
    /**
     * The policy rule number associated with the attachment.
     */
    readonly attachmentPolicyRuleNumber: pulumi.Output<number>;
    /**
     * The type of attachment.
     */
    readonly attachmentType: pulumi.Output<string>;
    /**
     * The ARN of a core network for the VPC attachment.
     */
    readonly coreNetworkArn: pulumi.Output<string>;
    /**
     * The ID of a core network where you're creating a site-to-site VPN attachment.
     */
    readonly coreNetworkId: pulumi.Output<string>;
    /**
     * Creation time of the attachment.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Region where the edge is located.
     */
    readonly edgeLocation: pulumi.Output<string>;
    /**
     * The name of the network function group attachment.
     */
    readonly networkFunctionGroupName: pulumi.Output<string | undefined>;
    /**
     * Owner account of the attachment.
     */
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * The Id of peering between transit gateway and core network.
     */
    readonly peeringId: pulumi.Output<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    readonly proposedNetworkFunctionGroupChange: pulumi.Output<outputs.networkmanager.TransitGatewayRouteTableAttachmentProposedNetworkFunctionGroupChange | undefined>;
    /**
     * The attachment to move from one segment to another.
     */
    readonly proposedSegmentChange: pulumi.Output<outputs.networkmanager.TransitGatewayRouteTableAttachmentProposedSegmentChange | undefined>;
    /**
     * The ARN of the Resource.
     */
    readonly resourceArn: pulumi.Output<string>;
    /**
     * The name of the segment that attachment is in.
     */
    readonly segmentName: pulumi.Output<string>;
    /**
     * The state of the attachment.
     */
    readonly state: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Arn of transit gateway route table.
     */
    readonly transitGatewayRouteTableArn: pulumi.Output<string>;
    /**
     * Last update time of the attachment.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a TransitGatewayRouteTableAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayRouteTableAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayRouteTableAttachment resource.
 */
export interface TransitGatewayRouteTableAttachmentArgs {
    /**
     * The name of the network function group attachment.
     */
    networkFunctionGroupName?: pulumi.Input<string>;
    /**
     * The Id of peering between transit gateway and core network.
     */
    peeringId: pulumi.Input<string>;
    /**
     * The attachment to move from one network function group to another.
     */
    proposedNetworkFunctionGroupChange?: pulumi.Input<inputs.networkmanager.TransitGatewayRouteTableAttachmentProposedNetworkFunctionGroupChangeArgs>;
    /**
     * The attachment to move from one segment to another.
     */
    proposedSegmentChange?: pulumi.Input<inputs.networkmanager.TransitGatewayRouteTableAttachmentProposedSegmentChangeArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The Arn of transit gateway route table.
     */
    transitGatewayRouteTableArn: pulumi.Input<string>;
}
