import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::PCAConnectorAD::ServicePrincipalName Resource Type
 */
export declare class ServicePrincipalName extends pulumi.CustomResource {
    /**
     * Get an existing ServicePrincipalName resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServicePrincipalName;
    /**
     * Returns true if the given object is an instance of ServicePrincipalName.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServicePrincipalName;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateConnector.html](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector.html) .
     */
    readonly connectorArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateDirectoryRegistration](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration.html) .
     */
    readonly directoryRegistrationArn: pulumi.Output<string | undefined>;
    /**
     * Create a ServicePrincipalName resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServicePrincipalNameArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServicePrincipalName resource.
 */
export interface ServicePrincipalNameArgs {
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateConnector.html](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector.html) .
     */
    connectorArn?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateDirectoryRegistration](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration.html) .
     */
    directoryRegistrationArn?: pulumi.Input<string>;
}
