import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of the AWS::QuickSight::DataSet Resource Type.
 */
export declare function getDataSet(args: GetDataSetArgs, opts?: pulumi.InvokeOptions): Promise<GetDataSetResult>;
export interface GetDataSetArgs {
    /**
     * The AWS account ID.
     */
    awsAccountId: string;
    /**
     * An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
     */
    dataSetId: string;
}
export interface GetDataSetResult {
    /**
     * <p>The Amazon Resource Name (ARN) of the resource.</p>
     */
    readonly arn?: string;
    /**
     * <p>Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.</p>
     */
    readonly columnGroups?: outputs.quicksight.DataSetColumnGroup[];
    /**
     * <p>A set of one or more definitions of a <code>
     *                <a href="https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ColumnLevelPermissionRule.html">ColumnLevelPermissionRule</a>
     *             </code>.</p>
     */
    readonly columnLevelPermissionRules?: outputs.quicksight.DataSetColumnLevelPermissionRule[];
    /**
     * <p>The amount of SPICE capacity used by this dataset. This is 0 if the dataset isn't
     *             imported into SPICE.</p>
     */
    readonly consumedSpiceCapacityInBytes?: number;
    /**
     * <p>The time that this dataset was created.</p>
     */
    readonly createdTime?: string;
    /**
     * The refresh properties of a dataset.
     */
    readonly dataSetRefreshProperties?: outputs.quicksight.DataSetRefreshProperties;
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     */
    readonly dataSetUsageConfiguration?: outputs.quicksight.DataSetUsageConfiguration;
    /**
     * <p>The parameter declarations of the dataset.</p>
     */
    readonly datasetParameters?: outputs.quicksight.DataSetDatasetParameter[];
    /**
     * Indicates whether you want to import the data into SPICE.
     */
    readonly importMode?: enums.quicksight.DataSetImportMode;
    /**
     * <p>The last time that this dataset was updated.</p>
     */
    readonly lastUpdatedTime?: string;
    /**
     * Configures the combination and transformation of the data from the physical tables.
     */
    readonly logicalTableMap?: {
        [key: string]: outputs.quicksight.DataSetLogicalTable;
    };
    /**
     * <p>The display name for the dataset.</p>
     */
    readonly name?: string;
    /**
     * <p>The list of columns after all transforms. These columns are available in templates,
     *             analyses, and dashboards.</p>
     */
    readonly outputColumns?: outputs.quicksight.DataSetOutputColumn[];
    /**
     * The performance optimization configuration of a dataset.
     */
    readonly performanceConfiguration?: outputs.quicksight.DataSetPerformanceConfiguration;
    /**
     * <p>A list of resource permissions on the dataset.</p>
     */
    readonly permissions?: outputs.quicksight.DataSetResourcePermission[];
    /**
     * Declares the physical tables that are available in the underlying data sources.
     */
    readonly physicalTableMap?: {
        [key: string]: outputs.quicksight.DataSetPhysicalTable;
    };
    /**
     * The row-level security configuration for the data that you want to create.
     */
    readonly rowLevelPermissionDataSet?: outputs.quicksight.DataSetRowLevelPermissionDataSet;
    /**
     * The element you can use to define tags for row-level security.
     */
    readonly rowLevelPermissionTagConfiguration?: outputs.quicksight.DataSetRowLevelPermissionTagConfiguration;
    /**
     * <p>Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.</p>
     */
    readonly tags?: outputs.Tag[];
    /**
     * The usage of the dataset.
     */
    readonly useAs?: enums.quicksight.DataSetUseAs;
}
/**
 * Definition of the AWS::QuickSight::DataSet Resource Type.
 */
export declare function getDataSetOutput(args: GetDataSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataSetResult>;
export interface GetDataSetOutputArgs {
    /**
     * The AWS account ID.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
     */
    dataSetId: pulumi.Input<string>;
}
