import * as pulumi from "@pulumi/pulumi";
/**
 * AWS::RoboMaker::RobotApplicationVersion resource creates an AWS RoboMaker RobotApplicationVersion. This helps you control which code your robot uses.
 */
export declare class RobotApplicationVersion extends pulumi.CustomResource {
    /**
     * Get an existing RobotApplicationVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RobotApplicationVersion;
    /**
     * Returns true if the given object is an instance of RobotApplicationVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RobotApplicationVersion;
    /**
     * The application information for the robot application.
     */
    readonly application: pulumi.Output<string>;
    /**
     * The robot application version.
     */
    readonly applicationVersion: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the robot application version.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The revision ID of robot application.
     */
    readonly currentRevisionId: pulumi.Output<string | undefined>;
    /**
     * Create a RobotApplicationVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RobotApplicationVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RobotApplicationVersion resource.
 */
export interface RobotApplicationVersionArgs {
    /**
     * The application information for the robot application.
     */
    application: pulumi.Input<string>;
    /**
     * The revision ID of robot application.
     */
    currentRevisionId?: pulumi.Input<string>;
}
