import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::RolesAnywhere::TrustAnchor Resource Type.
 */
export declare class TrustAnchor extends pulumi.CustomResource {
    /**
     * Get an existing TrustAnchor resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrustAnchor;
    /**
     * Returns true if the given object is an instance of TrustAnchor.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrustAnchor;
    /**
     * Indicates whether the trust anchor is enabled.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The name of the trust anchor.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of notification settings to be associated to the trust anchor.
     */
    readonly notificationSettings: pulumi.Output<outputs.rolesanywhere.TrustAnchorNotificationSetting[] | undefined>;
    /**
     * The trust anchor type and its related certificate data.
     */
    readonly source: pulumi.Output<outputs.rolesanywhere.TrustAnchorSource>;
    /**
     * The tags to attach to the trust anchor.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN of the trust anchor.
     */
    readonly trustAnchorArn: pulumi.Output<string>;
    /**
     * The unique identifier of the trust anchor.
     */
    readonly trustAnchorId: pulumi.Output<string>;
    /**
     * Create a TrustAnchor resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TrustAnchorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrustAnchor resource.
 */
export interface TrustAnchorArgs {
    /**
     * Indicates whether the trust anchor is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The name of the trust anchor.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of notification settings to be associated to the trust anchor.
     */
    notificationSettings?: pulumi.Input<pulumi.Input<inputs.rolesanywhere.TrustAnchorNotificationSettingArgs>[]>;
    /**
     * The trust anchor type and its related certificate data.
     */
    source: pulumi.Input<inputs.rolesanywhere.TrustAnchorSourceArgs>;
    /**
     * The tags to attach to the trust anchor.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
