import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::S3::StorageLens resource is an Amazon S3 resource type that you can use to create Storage Lens configurations.
 */
export declare class StorageLens extends pulumi.CustomResource {
    /**
     * Get an existing StorageLens resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): StorageLens;
    /**
     * Returns true if the given object is an instance of StorageLens.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is StorageLens;
    /**
     * This resource contains the details Amazon S3 Storage Lens configuration.
     */
    readonly storageLensConfiguration: pulumi.Output<outputs.s3.StorageLensConfiguration>;
    /**
     * A set of tags (key-value pairs) for this Amazon S3 Storage Lens configuration.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a StorageLens resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StorageLensArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a StorageLens resource.
 */
export interface StorageLensArgs {
    /**
     * This resource contains the details Amazon S3 Storage Lens configuration.
     */
    storageLensConfiguration: pulumi.Input<inputs.s3.StorageLensConfigurationArgs>;
    /**
     * A set of tags (key-value pairs) for this Amazon S3 Storage Lens configuration.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
