import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::MlflowTrackingServer
 */
export declare class MlflowTrackingServer extends pulumi.CustomResource {
    /**
     * Get an existing MlflowTrackingServer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MlflowTrackingServer;
    /**
     * Returns true if the given object is an instance of MlflowTrackingServer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MlflowTrackingServer;
    /**
     * The Amazon S3 URI for MLFlow Tracking Server artifacts.
     */
    readonly artifactStoreUri: pulumi.Output<string>;
    /**
     * A flag to enable Automatic SageMaker Model Registration.
     */
    readonly automaticModelRegistration: pulumi.Output<boolean | undefined>;
    /**
     * The MLFlow Version used on the MLFlow Tracking Server.
     */
    readonly mlflowVersion: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on behalf of the customer.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the MLFlow Tracking Server.
     */
    readonly trackingServerArn: pulumi.Output<string>;
    /**
     * The name of the MLFlow Tracking Server.
     */
    readonly trackingServerName: pulumi.Output<string>;
    /**
     * The size of the MLFlow Tracking Server.
     */
    readonly trackingServerSize: pulumi.Output<enums.sagemaker.MlflowTrackingServerTrackingServerSize | undefined>;
    /**
     * The start of the time window for maintenance of the MLFlow Tracking Server in UTC time.
     */
    readonly weeklyMaintenanceWindowStart: pulumi.Output<string | undefined>;
    /**
     * Create a MlflowTrackingServer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MlflowTrackingServerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MlflowTrackingServer resource.
 */
export interface MlflowTrackingServerArgs {
    /**
     * The Amazon S3 URI for MLFlow Tracking Server artifacts.
     */
    artifactStoreUri: pulumi.Input<string>;
    /**
     * A flag to enable Automatic SageMaker Model Registration.
     */
    automaticModelRegistration?: pulumi.Input<boolean>;
    /**
     * The MLFlow Version used on the MLFlow Tracking Server.
     */
    mlflowVersion?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on behalf of the customer.
     */
    roleArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the MLFlow Tracking Server.
     */
    trackingServerName?: pulumi.Input<string>;
    /**
     * The size of the MLFlow Tracking Server.
     */
    trackingServerSize?: pulumi.Input<enums.sagemaker.MlflowTrackingServerTrackingServerSize>;
    /**
     * The start of the time window for maintenance of the MLFlow Tracking Server in UTC time.
     */
    weeklyMaintenanceWindowStart?: pulumi.Input<string>;
}
