import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::SecurityHub::Hub resource represents the implementation of the AWS Security Hub service in your account. One hub resource is created for each Region in which you enable Security Hub.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const exampleHubWithTags = new aws_native.securityhub.Hub("exampleHubWithTags", {
 *     tags: {
 *         key1: "value1",
 *         key2: "value2",
 *     },
 *     enableDefaultStandards: true,
 *     controlFindingGenerator: "SECURITY_CONTROL",
 * });
 * export const hubArn = exampleHubWithTags.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const exampleHubWithTags = new aws_native.securityhub.Hub("exampleHubWithTags", {
 *     tags: {
 *         key1: "value1",
 *         key2: "value2",
 *     },
 *     enableDefaultStandards: true,
 *     controlFindingGenerator: "SECURITY_CONTROL",
 * });
 * export const hubArn = exampleHubWithTags.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const exampleHubWithTags = new aws_native.securityhub.Hub("exampleHubWithTags", {
 *     tags: {
 *         key1: "value1",
 *         key2: "value2",
 *     },
 *     enableDefaultStandards: false,
 *     controlFindingGenerator: "STANDARD_CONTROL",
 * });
 * export const hubArn = exampleHubWithTags.id;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const exampleHubWithTags = new aws_native.securityhub.Hub("exampleHubWithTags", {
 *     tags: {
 *         key1: "value1",
 *         key2: "value2",
 *     },
 *     enableDefaultStandards: false,
 *     controlFindingGenerator: "STANDARD_CONTROL",
 * });
 * export const hubArn = exampleHubWithTags.id;
 *
 * ```
 */
export declare class Hub extends pulumi.CustomResource {
    /**
     * Get an existing Hub resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Hub;
    /**
     * Returns true if the given object is an instance of Hub.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Hub;
    /**
     * An ARN is automatically created for the customer.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Whether to automatically enable new controls when they are added to standards that are enabled
     */
    readonly autoEnableControls: pulumi.Output<boolean | undefined>;
    /**
     * This field, used when enabling Security Hub, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub generates a single finding for a control check even when the check applies to multiple enabled standards.  If the value for this field is set to STANDARD_CONTROL, Security Hub generates separate findings for a control check when the check applies to multiple enabled standards.
     */
    readonly controlFindingGenerator: pulumi.Output<string | undefined>;
    /**
     * Whether to enable the security standards that Security Hub has designated as automatically enabled.
     */
    readonly enableDefaultStandards: pulumi.Output<boolean | undefined>;
    /**
     * The date and time when Security Hub was enabled in the account.
     */
    readonly subscribedAt: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Hub resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: HubArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Hub resource.
 */
export interface HubArgs {
    /**
     * Whether to automatically enable new controls when they are added to standards that are enabled
     */
    autoEnableControls?: pulumi.Input<boolean>;
    /**
     * This field, used when enabling Security Hub, specifies whether the calling account has consolidated control findings turned on. If the value for this field is set to SECURITY_CONTROL, Security Hub generates a single finding for a control check even when the check applies to multiple enabled standards.  If the value for this field is set to STANDARD_CONTROL, Security Hub generates separate findings for a control check when the check applies to multiple enabled standards.
     */
    controlFindingGenerator?: pulumi.Input<string>;
    /**
     * Whether to enable the security standards that Security Hub has designated as automatically enabled.
     */
    enableDefaultStandards?: pulumi.Input<boolean>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
