import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::SES::MailManagerAddonSubscription Resource Type
 */
export declare class MailManagerAddonSubscription extends pulumi.CustomResource {
    /**
     * Get an existing MailManagerAddonSubscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MailManagerAddonSubscription;
    /**
     * Returns true if the given object is an instance of MailManagerAddonSubscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MailManagerAddonSubscription;
    /**
     * The name of the Add On to subscribe to. You can only have one subscription for each Add On name.
     *
     * Valid Values: `TRENDMICRO_VSAPI | SPAMHAUS_DBL | ABUSIX_MAIL_INTELLIGENCE`
     */
    readonly addonName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the Add On subscription.
     */
    readonly addonSubscriptionArn: pulumi.Output<string>;
    /**
     * The unique ID of the Add On subscription.
     */
    readonly addonSubscriptionId: pulumi.Output<string>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MailManagerAddonSubscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MailManagerAddonSubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MailManagerAddonSubscription resource.
 */
export interface MailManagerAddonSubscriptionArgs {
    /**
     * The name of the Add On to subscribe to. You can only have one subscription for each Add On name.
     *
     * Valid Values: `TRENDMICRO_VSAPI | SPAMHAUS_DBL | ABUSIX_MAIL_INTELLIGENCE`
     */
    addonName: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
