import * as pulumi from "@pulumi/pulumi";
/**
 * Config the role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your AWS account while assisting with attack mitigation.
 */
export declare function getDrtAccess(args: GetDrtAccessArgs, opts?: pulumi.InvokeOptions): Promise<GetDrtAccessResult>;
export interface GetDrtAccessArgs {
    /**
     * The ID of the account that submitted the template.
     */
    accountId: string;
}
export interface GetDrtAccessResult {
    /**
     * The ID of the account that submitted the template.
     */
    readonly accountId?: string;
    /**
     * Authorizes the Shield Response Team (SRT) to access the specified Amazon S3 bucket containing log data such as Application Load Balancer access logs, CloudFront logs, or logs from third party sources. You can associate up to 10 Amazon S3 buckets with your subscription.
     */
    readonly logBucketList?: string[];
    /**
     * Authorizes the Shield Response Team (SRT) using the specified role, to access your AWS account to assist with DDoS attack mitigation during potential attacks. This enables the SRT to inspect your AWS WAF configuration and create or update AWS WAF rules and web ACLs.
     */
    readonly roleArn?: string;
}
/**
 * Config the role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your AWS account while assisting with attack mitigation.
 */
export declare function getDrtAccessOutput(args: GetDrtAccessOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDrtAccessResult>;
export interface GetDrtAccessOutputArgs {
    /**
     * The ID of the account that submitted the template.
     */
    accountId: pulumi.Input<string>;
}
