export declare const DocumentationPartLocationType: {
    readonly Api: "API";
    readonly Authorizer: "AUTHORIZER";
    readonly Model: "MODEL";
    readonly Resource: "RESOURCE";
    readonly Method: "METHOD";
    readonly PathParameter: "PATH_PARAMETER";
    readonly QueryParameter: "QUERY_PARAMETER";
    readonly RequestHeader: "REQUEST_HEADER";
    readonly RequestBody: "REQUEST_BODY";
    readonly Response: "RESPONSE";
    readonly ResponseHeader: "RESPONSE_HEADER";
    readonly ResponseBody: "RESPONSE_BODY";
};
/**
 * The type of API entity to which the documentation content applies. Valid values are `API` , `AUTHORIZER` , `MODEL` , `RESOURCE` , `METHOD` , `PATH_PARAMETER` , `QUERY_PARAMETER` , `REQUEST_HEADER` , `REQUEST_BODY` , `RESPONSE` , `RESPONSE_HEADER` , and `RESPONSE_BODY` . Content inheritance does not apply to any entity of the `API` , `AUTHORIZER` , `METHOD` , `MODEL` , `REQUEST_BODY` , or `RESOURCE` type.
 */
export type DocumentationPartLocationType = (typeof DocumentationPartLocationType)[keyof typeof DocumentationPartLocationType];
export declare const DomainNameAccessAssociationAccessAssociationSourceType: {
    readonly Vpce: "VPCE";
};
/**
 * The source type of the domain name access association resource.
 */
export type DomainNameAccessAssociationAccessAssociationSourceType = (typeof DomainNameAccessAssociationAccessAssociationSourceType)[keyof typeof DomainNameAccessAssociationAccessAssociationSourceType];
export declare const DomainNameRoutingMode: {
    readonly BasePathMappingOnly: "BASE_PATH_MAPPING_ONLY";
    readonly RoutingRuleThenBasePathMapping: "ROUTING_RULE_THEN_BASE_PATH_MAPPING";
    readonly RoutingRuleOnly: "ROUTING_RULE_ONLY";
};
/**
 * The routing mode for this domain name. The routing mode determines how API Gateway sends traffic from your custom domain name to your public APIs.
 */
export type DomainNameRoutingMode = (typeof DomainNameRoutingMode)[keyof typeof DomainNameRoutingMode];
export declare const DomainNameV2RoutingMode: {
    readonly BasePathMappingOnly: "BASE_PATH_MAPPING_ONLY";
    readonly RoutingRuleThenBasePathMapping: "ROUTING_RULE_THEN_BASE_PATH_MAPPING";
    readonly RoutingRuleOnly: "ROUTING_RULE_ONLY";
};
/**
 * The valid routing modes are [BASE_PATH_MAPPING_ONLY], [ROUTING_RULE_THEN_BASE_PATH_MAPPING] and [ROUTING_RULE_ONLY]. All other inputs are invalid.
 */
export type DomainNameV2RoutingMode = (typeof DomainNameV2RoutingMode)[keyof typeof DomainNameV2RoutingMode];
export declare const MethodIntegrationConnectionType: {
    readonly Internet: "INTERNET";
    readonly VpcLink: "VPC_LINK";
};
/**
 * The type of the network connection to the integration endpoint. The valid value is `INTERNET` for connections through the public routable internet or `VPC_LINK` for private connections between API Gateway and a network load balancer in a VPC. The default value is `INTERNET` .
 */
export type MethodIntegrationConnectionType = (typeof MethodIntegrationConnectionType)[keyof typeof MethodIntegrationConnectionType];
export declare const MethodIntegrationContentHandling: {
    readonly ConvertToBinary: "CONVERT_TO_BINARY";
    readonly ConvertToText: "CONVERT_TO_TEXT";
};
/**
 * Specifies how to handle request payload content type conversions. Supported values are `CONVERT_TO_BINARY` and `CONVERT_TO_TEXT` , with the following behaviors:
 *
 * If this property is not defined, the request payload will be passed through from the method request to integration request without modification, provided that the `passthroughBehavior` is configured to support payload pass-through.
 */
export type MethodIntegrationContentHandling = (typeof MethodIntegrationContentHandling)[keyof typeof MethodIntegrationContentHandling];
export declare const MethodIntegrationPassthroughBehavior: {
    readonly WhenNoMatch: "WHEN_NO_MATCH";
    readonly WhenNoTemplates: "WHEN_NO_TEMPLATES";
    readonly Never: "NEVER";
};
/**
 * Specifies how the method request body of an unmapped content type will be passed through the integration request to the back end without transformation. A content type is unmapped if no mapping template is defined in the integration or the content type does not match any of the mapped content types, as specified in `requestTemplates` . The valid value is one of the following: `WHEN_NO_MATCH` : passes the method request body through the integration request to the back end without transformation when the method request content type does not match any content type associated with the mapping templates defined in the integration request. `WHEN_NO_TEMPLATES` : passes the method request body through the integration request to the back end without transformation when no mapping template is defined in the integration request. If a template is defined when this option is selected, the method request of an unmapped content-type will be rejected with an HTTP 415 Unsupported Media Type response. `NEVER` : rejects the method request with an HTTP 415 Unsupported Media Type response when either the method request content type does not match any content type associated with the mapping templates defined in the integration request or no mapping template is defined in the integration request.
 */
export type MethodIntegrationPassthroughBehavior = (typeof MethodIntegrationPassthroughBehavior)[keyof typeof MethodIntegrationPassthroughBehavior];
export declare const MethodIntegrationResponseContentHandling: {
    readonly ConvertToBinary: "CONVERT_TO_BINARY";
    readonly ConvertToText: "CONVERT_TO_TEXT";
};
/**
 * Specifies how to handle response payload content type conversions. Supported values are `CONVERT_TO_BINARY` and `CONVERT_TO_TEXT` , with the following behaviors:
 *
 * If this property is not defined, the response payload will be passed through from the integration response to the method response without modification.
 */
export type MethodIntegrationResponseContentHandling = (typeof MethodIntegrationResponseContentHandling)[keyof typeof MethodIntegrationResponseContentHandling];
export declare const MethodIntegrationType: {
    readonly Aws: "AWS";
    readonly AwsProxy: "AWS_PROXY";
    readonly Http: "HTTP";
    readonly HttpProxy: "HTTP_PROXY";
    readonly Mock: "MOCK";
};
/**
 * Specifies an API method integration type. The valid value is one of the following:
 *
 * For the HTTP and HTTP proxy integrations, each integration can specify a protocol ( `http/https` ), port and path. Standard 80 and 443 ports are supported as well as custom ports above 1024. An HTTP or HTTP proxy integration with a `connectionType` of `VPC_LINK` is referred to as a private integration and uses a VpcLink to connect API Gateway to a network load balancer of a VPC.
 */
export type MethodIntegrationType = (typeof MethodIntegrationType)[keyof typeof MethodIntegrationType];
export declare const UsagePlanKeyKeyType: {
    readonly ApiKey: "API_KEY";
};
/**
 * The type of a UsagePlanKey resource for a plan customer.
 */
export type UsagePlanKeyKeyType = (typeof UsagePlanKeyKeyType)[keyof typeof UsagePlanKeyKeyType];
