export declare const CapacityReservationStatus: {
    readonly Pending: "PENDING";
    readonly Active: "ACTIVE";
    readonly Cancelling: "CANCELLING";
    readonly Cancelled: "CANCELLED";
    readonly Failed: "FAILED";
    readonly UpdatePending: "UPDATE_PENDING";
};
export type CapacityReservationStatus = (typeof CapacityReservationStatus)[keyof typeof CapacityReservationStatus];
export declare const DataCatalogStatus: {
    readonly CreateInProgress: "CREATE_IN_PROGRESS";
    readonly CreateComplete: "CREATE_COMPLETE";
    readonly CreateFailed: "CREATE_FAILED";
    readonly CreateFailedCleanupInProgress: "CREATE_FAILED_CLEANUP_IN_PROGRESS";
    readonly CreateFailedCleanupComplete: "CREATE_FAILED_CLEANUP_COMPLETE";
    readonly CreateFailedCleanupFailed: "CREATE_FAILED_CLEANUP_FAILED";
    readonly DeleteInProgress: "DELETE_IN_PROGRESS";
    readonly DeleteComplete: "DELETE_COMPLETE";
    readonly DeleteFailed: "DELETE_FAILED";
};
/**
 * The status of the creation or deletion of the data catalog. LAMBDA, GLUE, and HIVE data catalog types are created synchronously. Their status is either CREATE_COMPLETE or CREATE_FAILED. The FEDERATED data catalog type is created asynchronously.
 */
export type DataCatalogStatus = (typeof DataCatalogStatus)[keyof typeof DataCatalogStatus];
export declare const DataCatalogType: {
    readonly Lambda: "LAMBDA";
    readonly Glue: "GLUE";
    readonly Hive: "HIVE";
    readonly Federated: "FEDERATED";
};
/**
 * The type of data catalog to create: LAMBDA for a federated catalog, GLUE for AWS Glue Catalog, or HIVE for an external hive metastore. FEDERATED is a federated catalog for which Athena creates the connection and the Lambda function for you based on the parameters that you pass.
 */
export type DataCatalogType = (typeof DataCatalogType)[keyof typeof DataCatalogType];
export declare const WorkGroupEncryptionOption: {
    readonly SseS3: "SSE_S3";
    readonly SseKms: "SSE_KMS";
    readonly CseKms: "CSE_KMS";
};
/**
 * Indicates whether Amazon S3 server-side encryption with Amazon S3-managed keys (SSE-S3), server-side encryption with KMS-managed keys (SSE-KMS), or client-side encryption with KMS-managed keys (CSE-KMS) is used.
 */
export type WorkGroupEncryptionOption = (typeof WorkGroupEncryptionOption)[keyof typeof WorkGroupEncryptionOption];
export declare const WorkGroupS3AclOption: {
    readonly BucketOwnerFullControl: "BUCKET_OWNER_FULL_CONTROL";
};
/**
 * The Amazon S3 canned ACL that Athena should specify when storing query results. Currently the only supported canned ACL is BUCKET_OWNER_FULL_CONTROL
 */
export type WorkGroupS3AclOption = (typeof WorkGroupS3AclOption)[keyof typeof WorkGroupS3AclOption];
export declare const WorkGroupState: {
    readonly Enabled: "ENABLED";
    readonly Disabled: "DISABLED";
};
/**
 * The state of the workgroup: ENABLED or DISABLED.
 */
export type WorkGroupState = (typeof WorkGroupState)[keyof typeof WorkGroupState];
