export declare const FileSystemBackupPolicyStatus: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * Set the backup policy status for the file system.
 *   +  *ENABLED* - Turns automatic backups on for the file system.
 *   +  *DISABLED* - Turns automatic backups off for the file system.
 */
export type FileSystemBackupPolicyStatus = (typeof FileSystemBackupPolicyStatus)[keyof typeof FileSystemBackupPolicyStatus];
export declare const FileSystemProtectionReplicationOverwriteProtection: {
    readonly Disabled: "DISABLED";
    readonly Enabled: "ENABLED";
};
/**
 * The status of the file system's replication overwrite protection.
 *   +  ``ENABLED`` – The file system cannot be used as the destination file system in a replication configuration. The file system is writeable. Replication overwrite protection is ``ENABLED`` by default.
 *   +  ``DISABLED`` – The file system can be used as the destination file system in a replication configuration. The file system is read-only and can only be modified by EFS replication.
 *   +  ``REPLICATING`` – The file system is being used as the destination file system in a replication configuration. The file system is read-only and is modified only by EFS replication.
 *
 *  If the replication configuration is deleted, the file system's replication overwrite protection is re-enabled, the file system becomes writeable.
 */
export type FileSystemProtectionReplicationOverwriteProtection = (typeof FileSystemProtectionReplicationOverwriteProtection)[keyof typeof FileSystemProtectionReplicationOverwriteProtection];
export declare const MountTargetIpAddressType: {
    readonly Ipv4Only: "IPV4_ONLY";
    readonly Ipv6Only: "IPV6_ONLY";
    readonly DualStack: "DUAL_STACK";
};
/**
 * The IP address type for the mount target. The possible values are `IPV4_ONLY` (only IPv4 addresses), `IPV6_ONLY` (only IPv6 addresses), and `DUAL_STACK` (dual-stack, both IPv4 and IPv6 addresses). If you don’t specify an `IpAddressType` , then `IPV4_ONLY` is used.
 *
 * > The `IPAddressType` must match the IP type of the subnet. Additionally, the `IPAddressType` parameter overrides the value set as the default IP address for the subnet in the VPC. For example, if the `IPAddressType` is `IPV4_ONLY` and `AssignIpv6AddressOnCreation` is `true` , then IPv4 is used for the mount target. For more information, see [Modify the IP addressing attributes of your subnet](https://docs.aws.amazon.com/vpc/latest/userguide/subnet-public-ip.html) .
 */
export type MountTargetIpAddressType = (typeof MountTargetIpAddressType)[keyof typeof MountTargetIpAddressType];
