import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * This schema provides construct and validation rules for AWS-XRay SamplingRule resource parameters.
 */
export declare class SamplingRule extends pulumi.CustomResource {
    /**
     * Get an existing SamplingRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SamplingRule;
    /**
     * Returns true if the given object is an instance of SamplingRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SamplingRule;
    /**
     * The sampling rule ARN that was created or updated.
     */
    readonly ruleArn: pulumi.Output<string>;
    readonly ruleName: pulumi.Output<string | undefined>;
    /**
     * The sampling rule to be created or updated.
     */
    readonly samplingRule: pulumi.Output<outputs.xray.SamplingRule | undefined>;
    readonly samplingRuleRecord: pulumi.Output<outputs.xray.SamplingRuleRecord | undefined>;
    readonly samplingRuleUpdate: pulumi.Output<outputs.xray.SamplingRuleUpdate | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SamplingRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SamplingRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SamplingRule resource.
 */
export interface SamplingRuleArgs {
    ruleName?: pulumi.Input<string>;
    /**
     * The sampling rule to be created or updated.
     */
    samplingRule?: pulumi.Input<inputs.xray.SamplingRuleArgs>;
    samplingRuleRecord?: pulumi.Input<inputs.xray.SamplingRuleRecordArgs>;
    samplingRuleUpdate?: pulumi.Input<inputs.xray.SamplingRuleUpdateArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
